@@ -16,7 +16,7 @@
 from pecan import expose, abort, response, request
 from pecan.rest import RestController
 import wsmeext.pecan as wsme_pecan
-from wsme.exc import ClientSideError, InvalidInput
+from wsme.exc import ClientSideError
 from wsme import Unset
 # other controllers
 from nodes import NodesController
@@ -29,10 +29,9 @@ from libra.api.model.validators import LBPut, LBPost, LBResp, LBVipResp
 from libra.api.model.validators import LBRespNode
 from libra.api.library.gearman_client import submit_job
 from libra.api.acl import get_limited_to_project
-from libra.api.library.exp import OverLimit, IPOutOfRange
+from libra.api.library.exp import OverLimit, IPOutOfRange, NotFound
 from libra.api.library.ip_filter import ipfilter
 from pecan import conf
-from sqlalchemy import func
 from wsme import types as wtypes
 
 
@@ -79,16 +78,15 @@ class LoadBalancersController(RestController):
                         LoadBalancer.protocol,
                         LoadBalancer.port, LoadBalancer.algorithm,
                         LoadBalancer.status, LoadBalancer.created,
-                        LoadBalancer.updated,
-                        func.count(Node.id).label('nodeCount')
-                    ).join(LoadBalancer.nodes).\
-                        filter(LoadBalancer.tenantid == tenant_id).\
-                        filter(LoadBalancer.status != 'DELETED').\
-                        group_by(LoadBalancer).all()
+                        LoadBalancer.updated
+                    ).filter(LoadBalancer.tenantid == tenant_id).\
+                        filter(LoadBalancer.status != 'DELETED').all()
                 load_balancers = {'loadBalancers': []}
 
                 for lb in lbs:
                     lb = lb._asdict()
+                    lb['nodeCount'] = session.query(Node).\
+                        filter(Node.lbid == lb['id']).count()
                     lb['id'] = str(lb['id'])
                     load_balancers['loadBalancers'].append(lb)
             else:
@@ -96,20 +94,19 @@ class LoadBalancersController(RestController):
                     LoadBalancer.name, LoadBalancer.id, LoadBalancer.protocol,
                     LoadBalancer.port, LoadBalancer.algorithm,
                     LoadBalancer.status, LoadBalancer.created,
-                    LoadBalancer.updated, LoadBalancer.statusDescription,
-                    func.count(Node.id).label('nodeCount')
+                    LoadBalancer.updated, LoadBalancer.statusDescription
                 ).join(LoadBalancer.devices).\
-                    join(LoadBalancer.nodes).\
                     filter(LoadBalancer.tenantid == tenant_id).\
                     filter(LoadBalancer.id == self.lbid).\
-                    group_by(LoadBalancer).\
                     first()
 
                 if not load_balancers:
                     session.rollback()
-                    raise ClientSideError("Load Balancer ID not found")
+                    raise NotFound("Load Balancer ID not found")
 
                 load_balancers = load_balancers._asdict()
+                load_balancers['nodeCount'] = session.query(Node).\
+                    filter(Node.lbid == load_balancers['id']).count()
                 virtualIps = session.query(
                     Device.id, Device.floatingIpAddr
                 ).join(LoadBalancer.devices).\
@@ -257,9 +254,7 @@ class LoadBalancersController(RestController):
                     first()
                 if old_lb is None:
                     session.rollback()
-                    raise InvalidInput(
-                        'virtualIps', virtual_id, 'Invalid virtual IP provided'
-                    )
+                    raise NotFound('Invalid virtual IP provided')
 
                 if body.protocol == Unset or body.protocol.lower() == 'HTTP':
                     old_count = session.query(
@@ -386,7 +381,7 @@ class LoadBalancersController(RestController):
 
             if lb is None:
                 session.rollback()
-                raise ClientSideError('Load Balancer ID is not valid')
+                raise NotFound('Load Balancer ID is not valid')
 
             if body.name != Unset:
                 namelimit = session.query(Limits.value).\
@@ -439,9 +434,7 @@ class LoadBalancersController(RestController):
 
             if lb is None:
                 session.rollback()
-                raise ClientSideError("Load Balancer ID is not valid")
-            session.query(Node).\
-                filter(Node.lbid == load_balancer_id).delete()
+                raise NotFound("Load Balancer ID is not valid")
             lb.status = 'PENDING_DELETE'
             device = session.query(
                 Device.id, Device.name
